@@ -94,6 +94,10 @@ class ClassMapGenerator
             if ($blacklist && preg_match($blacklist, strtr(realpath($filePath), '\\', '/'))) {
                 continue;
             }
+            // check non-realpath of file for directories symlink in project dir
+            if ($blacklist && preg_match($blacklist, strtr($filePath, '\\', '/'))) {
+                continue;
+            }
 
             $classes = self::findClasses($filePath);
 
