@@ -103,13 +103,8 @@ class ValidatingArrayLoader implements LoaderInterface
             }
         }
 
-        if (isset($this->config['license'])) {
-            if (is_string($this->config['license'])) {
-                $this->validateRegex('license', '[A-Za-z0-9+. ()-]+');
-            } else {
-                $this->validateFlatArray('license', '[A-Za-z0-9+. ()-]+');
-            }
-
+        // check for license validity on newly updated branches
+        if (isset($this->config['license']) && (!$releaseDate || $releaseDate->getTimestamp() >= strtotime('-8days'))) {
             if (is_array($this->config['license']) || is_string($this->config['license'])) {
                 $licenses = (array) $this->config['license'];
 
@@ -132,28 +127,6 @@ class ValidatingArrayLoader implements LoaderInterface
                         'If the software is closed-source, you may use "proprietary" as license.',
                         json_encode($this->config['license'])
                     );
-                } else if (!$releaseDate || $releaseDate->format('Y-m-d H:i:s') >= '2018-01-20 00:00:00') { // only warn for deprecations for releases/branches that follow the introduction of deprecated licenses
-                    foreach ($licenses as $license) {
-                        $spdxLicense = $licenseValidator->getLicenseByIdentifier($license);
-                        if ($spdxLicense && $spdxLicense[3]) {
-                            if (preg_match('{^[AL]?GPL-[123](\.[01])?\+$}i', $license)) {
-                                $this->warnings[] = sprintf(
-                                    'License "%s" is a deprecated SPDX license identifier, use "'.str_replace('+', '', $license).'-or-later" instead',
-                                    $license
-                                );
-                            } elseif (preg_match('{^[AL]?GPL-[123](\.[01])?$}i', $license)) {
-                                $this->warnings[] = sprintf(
-                                    'License "%s" is a deprecated SPDX license identifier, use "'.$license.'-only" or "'.$license.'-or-later" instead',
-                                    $license
-                                );
-                            } else {
-                                $this->warnings[] = sprintf(
-                                    'License "%s" is a deprecated SPDX license identifier, see https://spdx.org/licenses/',
-                                    $license
-                                );
-                            }
-                        }
-                    }
                 }
             }
         }
